@@ -80,12 +80,12 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.aws_eks
-import aws_cdk.core
+import constructs
 import kong_core
 
 
 class KongEks(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="kong-control-plane.KongEks",
 ):
@@ -95,12 +95,13 @@ class KongEks(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         control_plane_cluster_props: aws_cdk.aws_eks.ClusterProps,
-        control_plane_node_props: aws_cdk.aws_eks.AutoScalingGroupCapacityOptions,
+        control_plane_node_props: aws_cdk.aws_eks.NodegroupOptions,
         hosted_zone_name: builtins.str,
+        license_secrets_name: builtins.str,
         namespace: builtins.str,
         rds_props: kong_core.RdsDatabaseProps,
     ) -> None:
@@ -110,6 +111,7 @@ class KongEks(
         :param control_plane_cluster_props: 
         :param control_plane_node_props: 
         :param hosted_zone_name: 
+        :param license_secrets_name: 
         :param namespace: 
         :param rds_props: 
 
@@ -121,6 +123,7 @@ class KongEks(
             control_plane_cluster_props=control_plane_cluster_props,
             control_plane_node_props=control_plane_node_props,
             hosted_zone_name=hosted_zone_name,
+            license_secrets_name=license_secrets_name,
             namespace=namespace,
             rds_props=rds_props,
         )
